import { useEffect } from 'react';
import { Routes, Route, Navigate, useNavigate } from 'react-router-dom'
import { useDispatch } from 'react-redux'
import { createTheme, ThemeProvider } from '@mui/material/styles';
import { setAccessToken, setUserInfo, setSelectInfo } from "./business/userSlice.js"
import { useCookies } from 'react-cookie';
import LoginPage from './LoginPage';
import MainPage from './MainPage';
import yzs from "./business/request.js";

const theme = createTheme({
  status: {
    danger: '#e53e3e',
  },
  palette: {
    primary: {
      main: '#FF595A',
      darker: '#FF595A',
    },
    neutral: {
      main: '#64748B',
      contrastText: '#fff',
    },
    black: {
      main: "#222222",
    }
  },
});

function App() {
  const dispatch = useDispatch();
  const navigate = useNavigate();
  const [cookies, setCookie, removeCookie] = useCookies(['accessToken']);

  useEffect(() => {
    if (cookies.accessToken) {
      dispatch(setAccessToken(cookies.accessToken));
      yzs.get_user_info(yzs.uniqueDeviceIdentifier(), cookies.accessToken).then(info => {
        dispatch(setUserInfo(info));
        yzs.user_select(yzs.uniqueDeviceIdentifier(), cookies.accessToken).then(info => {
          dispatch(setSelectInfo(info));
        });
      }).catch(error => {
        console.log(error)
        if (error.returnCode === "uc_0106") {
          removeCookie("accessToken");
          navigate("/login");
        }
      });
    }
  }, []);

  return (
    <div>
      <ThemeProvider theme={theme}>
        <Routes>
          <Route exact path="/" element={cookies.accessToken ? <MainPage /> : <Navigate to="/login" />} />
          <Route exact path="/login" element={<LoginPage />} />
        </Routes>
      </ThemeProvider>
    </div>
  );
}

export default App;
