import React, { useState } from 'react';
import { useNavigate } from "react-router-dom";
import yzs from "./business/request.js";
import styles from './LoginPage.module.css';
import { useSelector, useDispatch } from 'react-redux'
import {
    setAccount, setPassword, setVerificationCode,
    setFlushToken, setAccessToken, setUserInfo, setAgreeAgreement,
    setSelectInfo,
} from "./business/userSlice.js"
import logo from './assets/logo.png';
import { Container, Tab, Box, Snackbar, Alert, Button } from '@mui/material';
import TabPanel from '@mui/lab/TabPanel';
import { TabList } from '@mui/lab';
import TabContext from '@mui/lab/TabContext';
import DynamicCodeForm from './components/DynamicCodeForm.js';
import PasswordForm from './components/PasswordForm.js';
import { useCookies } from 'react-cookie';

export default function () {
    const navigate = useNavigate();
    const dispatch = useDispatch();
    const [cookies, setCookie] = useCookies(['accessToken']);
    const [firstEnter, setFirstEnter] = useState(true);
    const [value, setValue] = useState("1");
    const [message, setMessage] = useState("");
    const [openTooltip, setOpenTooltip] = useState(false);
    const account = useSelector(state => state.user.account)
    const password = useSelector(state => state.user.password)
    const verificationCode = useSelector(state => state.user.verificationCode)
    const agreeAgreement = useSelector(state => state.user.agreeAgreement)

    const handleChange = (event, newValue) => {
        setValue(newValue);
    };

    const handleTooltipClose = () => {
        setOpenTooltip(false);
    };

    const onAgreeChange = (event) => {
        dispatch(setAgreeAgreement(!agreeAgreement));
    }

    const accessToken = useSelector(state => state.user.accessToken)
    const flushToken = useSelector(state => state.user.flushToken)

    // const debug_test = () => {
    //     console.log("accessToken", accessToken, yzs.uniqueDeviceIdentifier());
    //     console.log("userExists", yzs.userExists(yzs.uniqueDeviceIdentifier(), account));
    //     testPromiseLoading(2000, "你好").then(v => {
    //         console.log(v);
    //     })
    // }

    const handleInputChange = (event) => {
        const { name, value } = event.target;
        if (name === 'username') {
            dispatch(setAccount(value));
            if (firstEnter) setFirstEnter(false);
        } else if (name === 'password') {
            dispatch(setPassword(value));
        } else if (name === 'verification_code') {
            dispatch(setVerificationCode(value));
        }
    };

    const handleSubmit = (event) => {
        event.preventDefault();
        let result = null;
        if (value === "1") {
            result = yzs.dynamic_code_login(yzs.uniqueDeviceIdentifier(), account, verificationCode);
        } else if (value === "2") {
            result = yzs.login(yzs.uniqueDeviceIdentifier(), account, password);
        }
        result.then(token => {
            dispatch(setFlushToken(token));
            yzs.get_access_token(yzs.uniqueDeviceIdentifier(), token).then(token => {
                // yzs.update_access_token(ip.payload, token);
                dispatch(setAccessToken(token));
                setCookie("accessToken", token)
                yzs.get_user_info(yzs.uniqueDeviceIdentifier(), token).then(info => {
                    dispatch(setUserInfo(info));
                    yzs.user_select(yzs.uniqueDeviceIdentifier(), token).then(info => {
                        dispatch(setSelectInfo(info));
                        navigate("/");
                    })
                });
            })
        }).catch(error => {
            console.log(error)
            setMessage(error);
            setOpenTooltip(true);
        });
    };

    return <div className={styles.loginPage}>
        <div className={styles.title}>
            <img className={styles.titleIcon} src={logo} />
            <h1 className={styles.titleText}>纽曼AI语记</h1>
        </div>
        <div className={styles.loginFrame}>
            <Container component="form" className={styles.form} onSubmit={handleSubmit}
                sx={{
                    width: 360,
                    height: 418,
                    backgroundColor: 'white',
                    display: "flex",
                    flexDirection: "column",
                    justifyContent: "center",
                    alignItems: "center",
                    boxShadow: "0px 5px 20px 0px rgba(146,0,1,0.1)",
                    borderRadius: 4,

                }}
            >
                <TabContext value={value}>
                    <Box>
                        <TabList
                            aria-label="basic tabs example" value={value} onChange={handleChange} >
                            <Tab label="手机动态码登录" value="1" />
                            <Tab label="账号密码登录" value="2" />
                        </TabList>
                    </Box>

                    <TabPanel value="1" >
                        <DynamicCodeForm udid={yzs.uniqueDeviceIdentifier()}
                            firstEnter={firstEnter}
                            agreeAgreement={agreeAgreement} onAgreeChange={onAgreeChange}
                            onChange={handleInputChange}
                        />
                    </TabPanel>
                    <TabPanel value="2" >
                        <PasswordForm firstEnter={firstEnter}
                            agreeAgreement={agreeAgreement} onAgreeChange={onAgreeChange}
                            onChange={handleInputChange}
                        />
                    </TabPanel>
                </TabContext>
            </Container>
            {/* <Button variant="contained" onClick={debug_test}>测试</Button> */}
        </div>
        <Snackbar
            anchorOrigin={{ vertical: 'bottom', horizontal: 'center' }}
            open={openTooltip}
            autoHideDuration={3500}
            onClose={handleTooltipClose}
        >
            <Alert severity="error">{message}</Alert>
        </Snackbar>
    </div>
}