import { React, useEffect, useState } from 'react';
import { useSelector, useDispatch } from 'react-redux'
import AppBar from './AppBar';
import RecordList from './components/RecordList';
import PlayerBar from './PlayerBar';
import yzs from "./business/request.js";
import { setList, fetchRecord } from "./business/recorderSlice.js"
import { CssBaseline, Box, Typography } from '@mui/material';
import Backdrop from '@mui/material/Backdrop';
import CircularProgress from '@mui/material/CircularProgress';
import RecordLyrics from './RecordLyrics';
import { styled } from '@mui/material/styles';
import expand from './assets/expand.png';
import close from './assets/close.png';
import empty_hint from './assets/empty_hint.png';

const drawerWidth = 240;

const lyricsBrowserStyle = {
    marginTop: 16,
    paddingBottom: 40,
    padding: 24,
}

const ClickHanlde = styled('div', { shouldForwardProp: (prop) => prop !== 'open' })(
    ({ theme, open }) => ({
        width: 18,
        height: 50,
        backgroundImage: `url(${open ? close : expand})`,
        position: "fixed",
        top: "50%",
        left: 0,
        zIndex: theme.zIndex.drawer + 1,
        transition: theme.transitions.create('left', {
            easing: theme.transitions.easing.sharp,
            duration: theme.transitions.duration.leavingScreen,
        }),
        ...(open && {
            transition: theme.transitions.create('left', {
                easing: theme.transitions.easing.easeOut,
                duration: theme.transitions.duration.enteringScreen,
            }),
            left: drawerWidth - 18,
        }),
    })
);


const Main = styled('main', { shouldForwardProp: (prop) => prop !== 'open' })(
    ({ theme, open }) => ({
        flex: 1,
        paddingTop: 0,
        paddingLeft: theme.spacing(3),
        paddingRight: theme.spacing(3),
        paddingBottom: theme.spacing(3),
        marginTop: 48,
        transition: theme.transitions.create('margin', {
            easing: theme.transitions.easing.sharp,
            duration: theme.transitions.duration.leavingScreen,
        }),
        marginLeft: `-${drawerWidth}px`,
        ...(open && {
            transition: theme.transitions.create('margin', {
                easing: theme.transitions.easing.easeOut,
                duration: theme.transitions.duration.enteringScreen,
            }),
            marginLeft: 0,
        }),
    }),
);

const LyricItem = ({ empty, hasLyric, currentLyric, currentTime }) => {
    if (empty) {
        return <div style={{
            height: "calc(100vh - 298px)",
            marginTop: 48,
            display: "flex",
            alignItems: "center",
            justifyContent: "center",
        }} >
            <div>
                <img style={{ maxWidth: "100%", marginBottom: 40, }} src={empty_hint} />
                <Typography align='center' color="#929292">这里空空如也，添加些东西吧</Typography>
            </div>
        </div>
    } else {
        return hasLyric ? <RecordLyrics style={lyricsBrowserStyle} currentLyric={currentLyric} currentTime={currentTime} /> :
            <div style={lyricsBrowserStyle}
            />
    }
}

const RecordPlayer = ({ loading, empty, playerBarWidth, currentTime, hasLyric, currentLyric }) => {
    if (loading) {
        return <Backdrop
            sx={{
                color: '#fff',
                zIndex: (theme) => theme.zIndex.drawer + 1,
                // marginLeft: "240px",
                marginTop: "45px",
            }}
            open >
            <CircularProgress color="inherit" />
        </Backdrop>
    } else {
        return <div>
            <PlayerBar width={playerBarWidth} currentTime={currentTime} lyric={currentLyric} />
            <LyricItem empty={empty} hasLyric={hasLyric} currentLyric={currentLyric} currentTime={currentTime} />
        </div>
    }
};

export default function () {
    const dispatch = useDispatch()
    const accessToken = useSelector(state => state.user.accessToken);
    const passportId = useSelector(state => state.user.passportId);
    const currentTime = useSelector(state => state.recorder.currentTime);
    const currentLyric = useSelector(state => state.recorder.currentLyric);
    const currentIndex = useSelector(state => state.recorder.currentIndex);
    const recordList = useSelector(state => state.recorder.list);
    const loading = useSelector(state => state.recorder.loading);
    const [playerBarWidth, setPlayerBarWidth] = useState(0);
    const [open, setOpen] = useState(true);
    const [hasLyric, setHasLyric] = useState(true);
    useEffect(() => {
        if (passportId <= 0) return;
        yzs.get_record_list(accessToken, passportId).then(list => {
            dispatch(setList(list));
            if (list.length > 0) {
                dispatch(fetchRecord(accessToken, 0, list.at(0)));
            }
        }).catch(error => {
            console.log("get list failed", error);
        });
    }, [passportId]);

    useEffect(() => {
        if (recordList.length <= 0) {
            setHasLyric(false);
            return;
        }
        setHasLyric((recordList.at(currentIndex).transResultUrl));
    }, [currentIndex, currentLyric]);

    const onClick = () => {
        setOpen(!open);
        setPlayerBarWidth(document.documentElement.clientWidth - 240 - 48); // 防止中途底部出现scrollbar
    }

    const handleResize = () => {
        // let scrollBarWidth = window.innerWidth - document.documentElement.clientWidth;
        setPlayerBarWidth(document.documentElement.clientWidth - (open ? 240 : 0) - 48);
    }

    const onTransitionEnd = () => {
        handleResize();
    }

    useEffect(() => {
        handleResize();
        window.addEventListener('resize', handleResize);
        return () => {
            window.removeEventListener('resize', handleResize);
        };
    }, []);

    useEffect(() => {
        if (!loading) handleResize();
    }, [loading]);

    return <Box sx={{ display: 'flex' }}>
        <CssBaseline />
        <AppBar />
        <RecordList open={open} recordList={recordList} currentIndex={currentIndex} />
        <ClickHanlde open={open} onClick={onClick} />
        <Main open={open}
            onTransitionEnd={onTransitionEnd}
        >
            <RecordPlayer loading={loading} empty={recordList.length <= 0}
                playerBarWidth={playerBarWidth} currentTime={currentTime} hasLyric={hasLyric} currentLyric={currentLyric} />
        </Main>
    </Box >
}