import React, { useMemo } from "react";
import { Typography, Paper } from "@mui/material";
import { useSelector, useDispatch } from 'react-redux'

function isHighlight(currentTime, { start, end }) {
    currentTime *= 1000;
    return (currentTime > start) && (currentTime <= end);
}

// type: 0 --> 声文速记   纯文本，已适配
// type: 1 --> 导入音频   
// type: 2 --> 同传翻译   纯文本，已适配
// type: 3 --> 双语对话

const PlainText = ({ lyrics }) => {
    if (typeof lyrics !== "string") return <React.Fragment />;
    return <div style={{ whiteSpace: "pre-wrap" }}>{lyrics}</div>
}

const ImportAudio = ({ lyrics, currentTime }) => {  // 导入音频
    if (typeof lyrics !== "object") return <React.Fragment />;
    const onClick = (index) => {
        console.log("onClick", index);
    }
    return <div>{lyrics.map((lyric, index) => {
        return <div style={{ paddingBottom: 10, display: "inline-block" }} onDoubleClick={() => onClick(index)}>
            <Typography align="left" color={isHighlight(currentTime, lyric) ? "red" : "black"}>{lyric.text}</Typography>
        </div>
    })}
    </div>
};

const BilingualDialogue = ({ lyrics }) => {  // 双语对话
    if (typeof lyrics !== "object") return <React.Fragment />;
    return <div> {lyrics.map((lyric, index) => {
        return <div index={index} style={{ paddingBottom: 40 }}>
            <Typography align="left" >{lyric.asr}</Typography>
            <Typography align="left" >{lyric.translate}</Typography>
        </div>
    })}</div>
}

const LyricsContent = ({ type, lyrics, currentTime }) => {
    if (type === 0 || type === 2) {
        return <PlainText lyrics={lyrics} />
    } else if (type === 1) {
        return <ImportAudio lyrics={lyrics} currentTime={currentTime} />
    } else if (type === 3) {
        return <BilingualDialogue lyrics={lyrics} />
    } else {
        return <React.Fragment />
    }
}

export default function ({ style, currentLyric, currentTime }) {
    const currentIndex = useSelector(state => state.recorder.currentIndex);
    const recordList = useSelector(state => state.recorder.list);
    const currentType = useMemo(() => {
        if (recordList.length <= 0) return -1;
        return recordList.at(currentIndex).type;
    }, [currentLyric]);
    return <Paper style={style}>
        <LyricsContent type={currentType} lyrics={currentLyric} currentTime={currentTime} />
    </Paper>
}