import { createSlice } from '@reduxjs/toolkit'
import yzs from "./request.js";

// type: 0 --> 声文速记   纯文本，已适配
// type: 1 --> 导入音频   
// type: 2 --> 同传翻译   纯文本，已适配
// type: 3 --> 双语对话

export const recorderSlice = createSlice({
    name: 'recorder',
    initialState: {
        list: [],
        currentIndex: 0,
        currentLyric: [],
        currentBlob: "",
        currentWaveData: [],
        currentTime: 0, // 当前音频播放时间
        pause: true,
        loading: false,
    },
    reducers: {
        setList: (state, action) => {
            state.list = action.payload;
        },
        setCurrentIndex: (state, action) => {
            state.pause = true;
            state.currentIndex = action.payload;
        },
        setCurrentLyric: (state, action) => {
            state.currentLyric = action.payload;
        },
        setCurrentBlob: (state, action) => {
            state.currentBlob = action.payload;
        },
        setCurrentTime: (state, action) => {
            state.currentTime = action.payload;
        },
        setCurrentWaveData: (state, action) => {
            state.currentWaveData = action.payload;
        },
        togglePauseState: (state) => {
            state.pause = !state.pause;
        },
        setPauseState: (state, action) => {
            state.pause = action.payload;
        },
        setLoading: (state, action) => {
            state.loading = true;
        },
        setLoadFinished: (state, action) => {
            state.loading = false;
        },
    }
})

// Action creators are generated for each case reducer function
export const {
    setCurrentIndex, setList, setCurrentLyric, setCurrentBlob, togglePauseState, setPauseState, setCurrentTime,
    setCurrentWaveData,
    setLoading,
    setLoadFinished,
} = recorderSlice.actions

export default recorderSlice.reducer

const fetchRecord = (accessToken, index, record) => {
    return (dispatch) => {
        dispatch(setLoading());
        let promises = [];
        if (record.transResultUrl) {
            let promise1 = yzs.download(accessToken, record.transResultUrl).then(
                blob => blob.text()
            ).then(text => {
                // console.log("type", record.type, text);
                let payload = null;
                if (record.type === 1 || record.type === 3) {
                    payload = JSON.parse(text)
                } else {
                    payload = text;
                }
                dispatch(setCurrentLyric(payload));
            });
            promises.push(promise1);
        }

        let promise2 = yzs.download(accessToken, record.audioUrl).then(blob => {
            dispatch(setCurrentBlob(URL.createObjectURL(blob)));
        });

        promises.push(promise2);
        Promise.all(promises).then(() => {
            dispatch(setLoadFinished());
        });
    };
}

export { fetchRecord };