// 间隔多长时间取一个采样点
// duration 秒，有小数点
const sampleInterval = (duration) => {
    let interval = 100;
    let isFirefox = window.navigator.userAgent.includes("Firefox");
    if (isFirefox) {// firefox canvas width 不能过长
        if (duration > 20 * 60) {
            interval = 400;
        } else if (duration > 10 * 60) {
            interval = 200;
        }
    } else {
        if (duration > 20 * 60) {
            interval = 200;
        }
    }
    return interval;
}

// interval 间隔ms采点
function audioWaveData(url, interval) {
    if (url.length <= 0) return;
    console.log("audioWaveData", url, interval);
    return fetch(url)
        .then(response => response.blob())
        .then(blob => blob.arrayBuffer())
        .then(arrayBuffer => {
            let context = new (window.AudioContext || window.webkitAudioContext)();
            return context.decodeAudioData(arrayBuffer).then(audioBuffer => {
                let pointsInterval = audioBuffer.sampleRate / 1000 * interval;
                let waveData = audioBuffer.getChannelData(0);
                let wave = [];
                let amplitude = 0;
                for (let i = 0; i < waveData.length; i++) {
                    amplitude += Math.abs(waveData[i]);
                    if (i % pointsInterval == 0) {
                        wave.push(Math.floor(amplitude * 500 / pointsInterval));
                        amplitude = 0;
                    }
                }
                return wave;
            })
        });
}

// type: 0 --> 声文速记   纯文本，已适配
// type: 1 --> 导入音频   
// type: 2 --> 同传翻译   纯文本，已适配
// type: 3 --> 双语对话
function exportRecordLyric(type, lyric, filename) {
    let element = document.createElement('a');

    let text = "";
    if (type === 0 || type === 2) {
        text = lyric;
    } else if (type === 1) {
        text = lyric.reduce((accumulator, currentValue) => accumulator + currentValue.text, text);
    } else if (type === 3) {
        text = lyric.reduce((accumulator, currentValue) => {
            if (currentValue.head) return accumulator;
            return accumulator + currentValue.asr + "\n" + currentValue.translate + "\n\n";
        }, text);
    }

    element.setAttribute('href', 'data:text/plain;charset=utf-8,' + encodeURIComponent(text));
    element.setAttribute('download', filename);

    element.style.display = 'none';
    document.body.appendChild(element);

    element.click();
    document.body.removeChild(element);
}

function validatePhoneNumber(phoneNumber) {
    if (phoneNumber.length !== 11) {
        return false;
    }
    let reg = /^1\d{10}$/;
    return reg.test(phoneNumber);
}

function textHintOfValidatePhoneNumber(phoneNumber) {
    if (validatePhoneNumber(phoneNumber)) return "";
    if (phoneNumber.length === 0) return "请输入手机号码"
    return "请输入正确的手机号码";
}

export { sampleInterval, audioWaveData, validatePhoneNumber, textHintOfValidatePhoneNumber, exportRecordLyric };