import React, { useState } from 'react';
import { Container, TextField, Button, InputAdornment } from "@mui/material";
import PhoneIphoneIcon from '@mui/icons-material/PhoneIphone';
import LockIcon from '@mui/icons-material/Lock';
import { useSelector, useDispatch } from 'react-redux'
import Agreement from './Agreement.js';
import { validatePhoneNumber, textHintOfValidatePhoneNumber } from "../business/utilities.js"

export default function ({ firstEnter, onChange, agreeAgreement, onAgreeChange }) {
    const account = useSelector(state => state.user.account)
    const password = useSelector(state => state.user.password)

    return <Container disableGutters={true}
        sx={{
            width: 300,
            height: 200,
        }}
    >
        <TextField
            name="username"
            autoComplete="username"
            hiddenLabel
            placeholder="请输入手机号码"
            variant="outlined"
            size="small"
            error={firstEnter ? false : !validatePhoneNumber(account)}
            helperText={firstEnter ? "" : textHintOfValidatePhoneNumber(account)}
            value={account}
            fullWidth
            onChange={onChange}
            InputProps={{
                startAdornment: (
                    <InputAdornment position="start">
                        <PhoneIphoneIcon />
                    </InputAdornment>
                ),
            }}
            sx={{
                minHeight: 64,
            }}
        />
        <TextField
            sx={{
                minHeight: 50,
            }}
            fullWidth
            name="password"
            hiddenLabel
            placeholder="请输入密码"
            type="password"
            autoComplete="current-password"
            variant="outlined"
            size="small"
            value={password}
            onChange={onChange}
            InputProps={{
                startAdornment: (
                    <InputAdornment position="start">
                        <LockIcon />
                    </InputAdornment>
                ),
            }}
        />
        <Button
            type="submit"
            variant="contained"
            color="primary"
            fullWidth
            disabled={!agreeAgreement}
            sx={{
                marginTop: 1.5,
                backgroundColor: "#FF595A",
                '&:hover': {
                    backgroundColor: '#FF595A',
                },
                '&:active': {
                    backgroundColor: '#FF595A',
                },
            }}
        >
            登录
        </Button>
        <Agreement agree={agreeAgreement} onChange={onAgreeChange} />
    </Container>
}